@@ -17,11 +17,11 @@ eLCM functionality.
 """
 
 import collections
-import six
 import time
 
 from oslo_serialization import jsonutils
 import requests
+import six
 
 from scciclient.irmc import scci
 
@@ -1092,8 +1092,8 @@ def set_bios_configuration(irmc_info, settings):
     if server_version:
         bios_config_data['Server']['@Version'] = server_version
     if bios_version:
-        bios_config_data['Server']['SystemConfig']['BiosConfig']['@Version'] = \
-            bios_version
+        (bios_config_data['Server']['SystemConfig']['BiosConfig']
+            ['@Version']) = bios_version
 
     configs = {}
     for setting_param in settings:
